﻿using System;
using System.Collections.Generic;

using DevExpress.XtraEditors;
using DevExpress.XtraEditors.Controls;
using DevExpress.XtraEditors.Repository;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 카테고리 리스트
        /// </summary>
        private List<Category> categoryList = new List<Category>();

        /// <summary>
        /// 제품 리스트
        /// </summary>
        private List<Product> productList = new List<Product>();

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load += Form_Load;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.categoryList = Category.GetList();

            this.productList = Product.GetList();

            this.gridControl.DataSource = this.productList;

            this.gridView.Columns["UnitPrice"].DisplayFormat.FormatType   = DevExpress.Utils.FormatType.Numeric;
            this.gridView.Columns["UnitPrice"].DisplayFormat.FormatString = "c2";

            RepositoryItemLookUpEdit repositoryItemLookUpEdit = new RepositoryItemLookUpEdit();

            repositoryItemLookUpEdit.ValueMember           = "ID";
            repositoryItemLookUpEdit.DisplayMember         = "CategoryName";
            repositoryItemLookUpEdit.BestFitMode           = BestFitMode.BestFitResizePopup;
            repositoryItemLookUpEdit.DropDownRows          = this.categoryList.Count;
            repositoryItemLookUpEdit.SearchMode            = SearchMode.AutoComplete;
            repositoryItemLookUpEdit.AutoSearchColumnIndex = 1;
            repositoryItemLookUpEdit.DataSource            = this.categoryList;

            this.gridView.Columns["CategoryID"].ColumnEdit = repositoryItemLookUpEdit;

            this.gridView.BestFitColumns();
        }

        #endregion
    }
}